# automatically generated by the FlatBuffers compiler, do not modify

# namespace: isp

class MessageBody(object):
    NONE = 0
    ClientHandshake = 1
    ServerHandshake = 2
    Initialize = 3
    State = 4
    Obs = 5
    Command = 6
    Tensor = 7
    Dict = 8
    SensorsDict = 9
    SensorsDataDict = 10
    BoundingBox = 11
