# automatically generated by the FlatBuffers compiler, do not modify

# namespace: isp

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

class Resolution(object):
    __slots__ = ['_tab']

    @classmethod
    def SizeOf(cls):
        return 8

    # Resolution
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Resolution
    def Width(self): return self._tab.Get(flatbuffers.number_types.Int32Flags, self._tab.Pos + flatbuffers.number_types.UOffsetTFlags.py_type(0))
    # Resolution
    def Height(self): return self._tab.Get(flatbuffers.number_types.Int32Flags, self._tab.Pos + flatbuffers.number_types.UOffsetTFlags.py_type(4))

def CreateResolution(builder, width, height):
    builder.Prep(4, 8)
    builder.PrependInt32(height)
    builder.PrependInt32(width)
    return builder.Offset()
