# automatically generated by the FlatBuffers compiler, do not modify

# namespace: isp

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

class ServerHandshake(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = ServerHandshake()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsServerHandshake(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    @classmethod
    def ServerHandshakeBufferHasIdentifier(cls, buf, offset, size_prefixed=False):
        return flatbuffers.util.BufferHasIdentifier(buf, offset, b"\x49\x53\x50\x46", size_prefixed=size_prefixed)

    # ServerHandshake
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # ServerHandshake
    def SystemName(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # ServerHandshake
    def ModelName(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

def ServerHandshakeStart(builder): builder.StartObject(2)
def Start(builder):
    return ServerHandshakeStart(builder)
def ServerHandshakeAddSystemName(builder, systemName): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(systemName), 0)
def AddSystemName(builder, systemName):
    return ServerHandshakeAddSystemName(builder, systemName)
def ServerHandshakeAddModelName(builder, modelName): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(modelName), 0)
def AddModelName(builder, modelName):
    return ServerHandshakeAddModelName(builder, modelName)
def ServerHandshakeEnd(builder): return builder.EndObject()
def End(builder):
    return ServerHandshakeEnd(builder)