# automatically generated by the FlatBuffers compiler, do not modify

# namespace: isp

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

class SensorsDataDict(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = SensorsDataDict()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsSensorsDataDict(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    @classmethod
    def SensorsDataDictBufferHasIdentifier(cls, buf, offset, size_prefixed=False):
        return flatbuffers.util.BufferHasIdentifier(buf, offset, b"\x49\x53\x50\x46", size_prefixed=size_prefixed)

    # SensorsDataDict
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # SensorsDataDict
    def SensorsData(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = self._tab.Vector(o)
            x += flatbuffers.number_types.UOffsetTFlags.py_type(j) * 4
            x = self._tab.Indirect(x)
            from communications.isp.SensorData import SensorData
            obj = SensorData()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # SensorsDataDict
    def SensorsDataLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # SensorsDataDict
    def SensorsDataIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        return o == 0

def SensorsDataDictStart(builder): builder.StartObject(1)
def Start(builder):
    return SensorsDataDictStart(builder)
def SensorsDataDictAddSensorsData(builder, sensorsData): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(sensorsData), 0)
def AddSensorsData(builder, sensorsData):
    return SensorsDataDictAddSensorsData(builder, sensorsData)
def SensorsDataDictStartSensorsDataVector(builder, numElems): return builder.StartVector(4, numElems, 4)
def StartSensorsDataVector(builder, numElems):
    return SensorsDataDictStartSensorsDataVector(builder, numElems)
def SensorsDataDictEnd(builder): return builder.EndObject()
def End(builder):
    return SensorsDataDictEnd(builder)