# automatically generated by the FlatBuffers compiler, do not modify

# namespace: isp

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

class Action(object):
    __slots__ = ['_tab']

    @classmethod
    def SizeOf(cls):
        return 16

    # Action
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Action
    def Acceleration(self): return self._tab.Get(flatbuffers.number_types.Float64Flags, self._tab.Pos + flatbuffers.number_types.UOffsetTFlags.py_type(0))
    # Action
    def Steering(self): return self._tab.Get(flatbuffers.number_types.Float64Flags, self._tab.Pos + flatbuffers.number_types.UOffsetTFlags.py_type(8))

def CreateAction(builder, acceleration, steering):
    builder.Prep(8, 16)
    builder.PrependFloat64(steering)
    builder.PrependFloat64(acceleration)
    return builder.Offset()
